@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Module::List qw(list_modules);
 use Module::Load;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my $self;
 
@@ -26,24 +26,12 @@ sub import {
         *{"$pkg\::$sub_name"} = \&_plugins;
     }
 }
-sub _config {
-    my ($self, %opts) = @_;
-    for (keys %opts){
-        $self->{$_} = $opts{$_};
-    }
-    return $self;
-}
 sub _new {
     my ($class, %args) = @_;
     my $self = bless \%args, $class;
 
     return $self;
 }
-sub _cache {
-    if ($self->{cache}){
-        return @{ $self->{modules} } if $self->{modules};
-    }
-}
 sub _search {
     my ($self, $pkg, $item) = @_;
 
@@ -67,7 +55,13 @@ sub _search {
         my $path = $pkg;
         $path .= '::Plugin::';
         my $candidates = {};
-        eval { $candidates = list_modules($path, {list_modules => 1, recurse => 1}); };
+        eval { $candidates = list_modules(
+                $path,
+                {
+                    list_modules => 1,
+                    recurse => 1}
+                );
+        };
         push @plugins, keys %$candidates;
     }
 
@@ -126,9 +120,6 @@ sub _plugins {
             if (-e $item){
                 @plugins = $self->_load($item);
             }
-            else {
-                return undef;
-            }
         }
         else{
             @plugins = $self->_search($pkg, $item);
@@ -137,14 +128,14 @@ sub _plugins {
     if (! @plugins){
         @plugins = _search($pkg);
     }
-    if (! @plugins && $self->{default}){
-        push @plugins, $self->{default};
+    if (! $plugins[0] && $self->{default}){
+        push @plugins, $self->_load($self->{default});
     }
 
     my @wanted_plugins;
 
     if ($can) {
-        for my $mod (@plugins) {
+        for my $mod (@plugins){
             my $can_count = 0;
             for my $sub (@$can){
                 if ($mod->can($sub)){
@@ -194,6 +185,10 @@ Plugin::Simple - Load plugins from files or modules.
     use Plugin::Simple sub_name => 'foo';
     @plugins = foo(...);
 
+    # set a default fallback plugin if searching turns up nothing
+
+    use Plugin::Simple default => 'My::Module::Plugin::DefaultPlugin'
+
     # do something with the plugins
 
     for my $plugin (@plugins){
@@ -214,11 +209,22 @@ It searches for modules in installed packages or non-installed files, and loads
 them (without string C<eval>). You can optionally have us return only the
 plugins that C<can()> perform a specific task.
 
+=head1 LOAD OPTIONS
+
+By default, we force C<plugins()> into your namespace. To change this name:
+
+    use Plugin::Simple sub_name => 'other_name';
+
+If searching fails, you can ensure a default known plugin gets loaded:
+
+    use Plugin::Simple default => 'My::Plugin';
+
+To use both options, simply separate them with a comma.
+
 =head1 FUNCTIONS/METHODS
 
 None. We simply install a C<plugin()> function within the namespace of the
-package that C<use>d us. To specify a different sub name, use this module as
-such: C<use Plugin::Simple sub_name =E<gt> 'name_of_sub';>.
+package that C<use>d us.
 
 =head1 AUTHOR
 
